@@ -1,13 +1,13 @@
 import logging
 import json
 from threading import Thread
-from functools import partial
+from secrets import token_hex
 from time import sleep
 from typing import Callable, Dict, List, Literal, Optional, Union
 from collections import defaultdict
 from functools import wraps
 from kafka import KafkaConsumer
-from kafka.coordinator.consumer import ConsumerCoordinator
+from kafka.errors import KafkaError, CommitFailedError
 from kafka.consumer.fetcher import ConsumerRecord
 from django.conf import settings
 
@@ -69,14 +69,6 @@ class Consumer:
 
     def run(self):
         for topic in self.handlers.keys():
-            self.kafka_consumers[topic] = KafkaConsumer(
-                topic,
-                bootstrap_servers=self.bootstrap_servers,
-                client_id=self.client_id,
-                group_id=self.group_id,
-                **self._kwargs,
-            )
-
             self.threads[topic] = Thread(target=self.consume_messages, kwargs={'topic': topic}, daemon=True)
             self.threads[topic].start()
 
@@ -90,20 +82,37 @@ class Consumer:
             sleep(5)
 
     def consume_messages(self, topic: str):
+        self.kafka_consumers[topic] = KafkaConsumer(
+            topic,
+            bootstrap_servers=self.bootstrap_servers,
+            client_id=f'{self.client_id}-{token_hex(4)}-{topic}',
+            group_id=self.group_id,
+            **self._kwargs,
+        )
+
         message: ConsumerRecord
         for message in self.kafka_consumers[topic]:
-            tries = 0
+            tries: int = 0
             while True:
                 tries += 1
                 try:
                     self._dispatch(message)
 
-                except Exception as error:
-                    self.logger.warning("Error occurred while processing message: %s", error)
-                    if tries >= 20:
-                        raise error
+                except CommitFailedError:
+                    # Topic partition offset commit failed
+                    raise
 
-                    sleep(tries * 0.05)
+                except KafkaError:
+                    raise
+
+                except Exception as error:
+                    self.logger.exception(error)
+
+                    if tries >= 25:
+                        sleep(5)
+
+                    else:
+                        sleep(tries ** 1.425 * 0.05)
 
                 else:
                     break
